[evolution] Bug #346438 - Error dialog too wide.



commit 4074ffa416ce27a1e3e85ec049a149d8323093c1
Author: Vibha Yadav <yvibha novell com>
Date:   Tue Sep 14 09:54:47 2010 +0530

    Bug #346438 - Error dialog too wide.
    
    The patch suggests displaying the calendar name and group instead of uri
    for the source of error.

 modules/calendar/e-cal-shell-sidebar.c |   20 ++++++++++----------
 1 files changed, 10 insertions(+), 10 deletions(-)
---
diff --git a/modules/calendar/e-cal-shell-sidebar.c b/modules/calendar/e-cal-shell-sidebar.c
index 8ddf8ac..3ae662a 100644
--- a/modules/calendar/e-cal-shell-sidebar.c
+++ b/modules/calendar/e-cal-shell-sidebar.c
@@ -149,32 +149,32 @@ cal_shell_sidebar_backend_error_cb (ECalShellSidebar *cal_shell_sidebar,
 	EShellWindow *shell_window;
 	EShellSidebar *shell_sidebar;
 	GtkWidget *dialog;
-	const gchar *uri;
-	gchar *uri_no_passwd;
+	const gchar *cal_name;
+	const gchar *cal_group;
 
 	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
-	uri = e_cal_get_uri (client);
-	uri_no_passwd = get_uri_without_password (uri);
+	cal_name = e_source_peek_name ( e_cal_get_source ( client ));
+	cal_group = e_source_group_peek_name ( e_source_peek_group( e_cal_get_source ( client)));
 
 	/* Translators: This string is displayed in a message dialog when
 	 *              our connection to the calendar service detects an
 	 *              out-of-band error.  The first string is a URI for
 	 *              the source of the error, the second string is the
 	 *              error message. */
 	dialog = gtk_message_dialog_new (
 		GTK_WINDOW (shell_window),
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		_("Error on %s\n%s"),
-		uri_no_passwd, message);
+		_("Error on %s: %s\n%s"),
+		cal_group, cal_name, message);
 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	g_free (uri_no_passwd);
 }
 
 static void
@@ -149,32 +149,32 @@ cal_shell_sidebar_backend_error_cb (ECalShellSidebar *cal_shell_sidebar,
 	/* Translators: This string is displayed in a message dialog when
 	 *              our connection to the calendar service detects an
-	 *              out-of-band error.  The first string is a URI for
-	 *              the source of the error, the second string is the
-	 *              error message. */
+	 *              out-of-band error.  The first string is a name of 
+	 *              group in which calendar for the source of error is
+	 *              defined and the second string is name of calendar 
+	 *              and the third string is the error message. */
 	dialog = gtk_message_dialog_new (
 		GTK_WINDOW (shell_window),



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]